@@ -189,10 +189,11 @@ gnc_ui_accounts_recurse (Account *parent, GList **currency_list,
         case ACCT_TYPE_RECEIVABLE:
             end_amount = xaccAccountGetBalanceAsOfDate(account, options.end_date);
             end_amount_default_currency =
-                gnc_pricedb_convert_balance_nearest_price (pricedb, end_amount,
-                                                           account_currency,
-                                                           to_curr,
-                                                           options.end_date);
+                gnc_pricedb_convert_balance_nearest_price_t64 (pricedb,
+                                                               end_amount,
+                                                               account_currency,
+                                                               to_curr,
+                                                               options.end_date);
 
             if (!non_currency || options.non_currency)
             {
@@ -224,17 +225,18 @@ gnc_ui_accounts_recurse (Account *parent, GList **currency_list,
         case ACCT_TYPE_EXPENSE:
             start_amount = xaccAccountGetBalanceAsOfDate(account, options.start_date);
             start_amount_default_currency =
-                gnc_pricedb_convert_balance_nearest_price (pricedb,
-                                                           start_amount,
-                                                           account_currency,
-                                                           to_curr,
-                                                           options.start_date);
+                gnc_pricedb_convert_balance_nearest_price_t64 (pricedb,
+                                                              start_amount,
+                                                              account_currency,
+                                                              to_curr,
+                                                              options.start_date);
             end_amount = xaccAccountGetBalanceAsOfDate(account, options.end_date);
             end_amount_default_currency =
-                gnc_pricedb_convert_balance_nearest_price (pricedb, end_amount,
-                                                           account_currency,
-                                                           to_curr,
-                                                           options.end_date);
+                gnc_pricedb_convert_balance_nearest_price_t64 (pricedb,
+                                                               end_amount,
+                                                               account_currency,
+                                                               to_curr,
+                                                               options.end_date);
 
             if (!non_currency || options.non_currency)
             {
@@ -357,10 +359,10 @@ gnc_main_window_summary_refresh (GNCMainSummary * summary)
 
 
     root = gnc_get_current_root_account ();
-    options.default_currency = xaccAccountGetCommodity(root);
+    options.default_currency = gnc_default_currency ();
     if (options.default_currency == NULL)
     {
-        options.default_currency = gnc_default_currency ();
+        options.default_currency = xaccAccountGetCommodity(root);
     }
 
     options.grand_total =
@@ -430,25 +432,18 @@ gnc_main_window_summary_refresh (GNCMainSummary * summary)
         gtk_combo_box_set_active(GTK_COMBO_BOX(summary->totals_combo), 0);
     }
 
-    /* Free the list we created for this */
-    for (current = g_list_first(currency_list);
-            current;
-            current = g_list_next(current))
-    {
-        g_free(current->data);
-    }
-    g_list_free(currency_list);
+    g_list_free_full (currency_list, g_free);
 }
 
 static gchar*
-get_negative_color (void)
+get_negative_color_str (void)
 {
     GdkRGBA color;
     GdkRGBA *rgba;
     gchar *color_str;
     GtkWidget *label = gtk_label_new ("Color");
     GtkStyleContext *context = gtk_widget_get_style_context (GTK_WIDGET(label));
-    gtk_style_context_add_class (context, "negative-numbers");
+    gtk_style_context_add_class (context, "gnc-class-negative-numbers");
     gtk_style_context_get_color (context, GTK_STATE_FLAG_NORMAL, &color);
     rgba = gdk_rgba_copy (&color);
 
@@ -465,7 +460,7 @@ summarybar_update_color (gpointer gsettings, gchar *key, gpointer user_data)
 {
     GNCMainSummary *summary = user_data;
 
-    summary->negative_color = get_negative_color();
+    summary->negative_color = get_negative_color_str();
     summary->show_negative_color = gnc_prefs_get_bool (GNC_PREFS_GROUP_GENERAL, GNC_PREF_NEGATIVE_IN_RED);
 
     gnc_main_window_summary_refresh (summary);
@@ -632,13 +627,13 @@ gnc_main_window_summary_new (void)
     retval->hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 5);
     gtk_box_set_homogeneous (GTK_BOX (retval->hbox), FALSE);
 
-    // Set the style context for this widget so it can be easily manipulated with css
-    gnc_widget_set_style_context (GTK_WIDGET(retval->hbox), "summary-bar");
+    // Set the name for this wodget so it can be easily manipulated with css
+    gtk_widget_set_name (GTK_WIDGET(retval->hbox), "gnc-id-account-summary-bar");
 
     retval->totals_combo = gtk_combo_box_new_with_model (GTK_TREE_MODEL (retval->datamodel));
     g_object_unref (retval->datamodel);
 
-    retval->negative_color = get_negative_color();
+    retval->negative_color = get_negative_color_str();
     retval->show_negative_color = gnc_prefs_get_bool (GNC_PREFS_GROUP_GENERAL, GNC_PREF_NEGATIVE_IN_RED);
     gnc_prefs_register_cb (GNC_PREFS_GROUP_GENERAL, GNC_PREF_NEGATIVE_IN_RED,
                           summarybar_update_color, retval);
