@@ -1408,7 +1408,8 @@ starting_balance_helper (Account *account, hierarchy_data *data)
     balance = get_final_balance (data->balance_hash, account);
     if (gnc_reverse_balance(account))
         balance = gnc_numeric_neg(balance);
-    if (!gnc_numeric_zero_p (balance))
+    if (!gnc_numeric_zero_p (balance) &&
+        gnc_commodity_is_currency (xaccAccountGetCommodity (account)))
         gnc_account_create_opening_balance (account, balance, gnc_time (NULL),
                                             gnc_get_current_book ());
 }
