@@ -76,8 +76,6 @@
 #include "gnc-icons.h"
 #include "print-session.h"
 
-#define WINDOW_REPORT_CM_CLASS "window-report"
-
 /* NW: you can add GNC_MOD_REPORT to gnc-engine.h
 or simply define it locally. Any unique string with
 a gnucash- prefix will do. Then just set a log level
@@ -497,6 +495,8 @@ gnc_plugin_page_report_create_widget( GncPluginPage *page )
     gnc_plugin_page_report_load_cb (priv->html, type, id_name, url_label, report);
     g_free(id_name);
     g_free(child_name);
+    g_free (url_label);
+    g_free (url_location);
 
     // FIXME.  This is f^-1(f(x)), isn't it?
     DEBUG( "id=%d", priv->reportId );
@@ -1194,10 +1194,10 @@ gnc_plugin_page_report_constr_init(GncPluginPageReport *plugin_page, gint report
     gchar *saved_reports_path = gnc_build_userdata_path (SAVED_REPORTS_FILE);
     gchar *report_save_str = g_strdup_printf (
         _("Update the current report's saved configuration. "
-        "The report configuration will be saved in the file %s. "), saved_reports_path);
+          "The report configuration will be saved in the file %s."), saved_reports_path);
     gchar *report_saveas_str = g_strdup_printf (
-        _("Add the current report's configuration to the `Reports->Saved Report Configurations' menu. "
-        "The report configuration will be saved in the file %s. "), saved_reports_path);
+        _("Add the current report's configuration to the 'Reports->Saved Report Configurations' menu. "
+          "The report configuration will be saved in the file %s."), saved_reports_path);
 
     GtkActionEntry report_actions[] =
     {
@@ -1722,7 +1722,7 @@ gnc_plugin_page_report_export_cb( GtkAction *action, GncPluginPageReport *report
     if (scm_is_pair (choice))
     {
         SCM type = scm_cdr (choice);
-        SCM document = scm_call_3 (export_thunk, priv->cur_report, type, SCM_BOOL_F);
+        SCM document = scm_call_2 (export_thunk, priv->cur_report, type);
         SCM query_result = scm_c_eval_string ("gnc:html-document?");
         SCM get_export_string = scm_c_eval_string ("gnc:html-document-export-string");
         SCM get_export_error = scm_c_eval_string ("gnc:html-document-export-error");
